@@ -22,7 +22,7 @@
 #include "config.h"
 
 #include <glib.h>
-#include <glib/gi18n-lib.h>
+#include <glib/gi18n.h>
 #include <gtk/gtk.h>
 #include <gdk/gdk.h>
 #include <gdk/gdkx.h>
@@ -121,8 +121,10 @@ csd_wacom_stylus_finalize (GObject *object)
 }
 
 static const char *
-get_icon_name_from_type (WacomStylusType type)
+get_icon_name_from_type (const WacomStylusType *wstylus)
 {
+	WacomStylusType type = libwacom_stylus_get_type (wstylus);
+
 	switch (type) {
 	case WSTYLUS_INKING:
 	case WSTYLUS_STROKE:
@@ -135,9 +137,36 @@ get_icon_name_from_type (WacomStylusType type)
 		return "wacom-stylus-art-pen";
 	case WSTYLUS_CLASSIC:
 		return "wacom-stylus-classic";
-	default:
-		return "wacom-stylus";
-	}
+#ifdef HAVE_WACOM_3D_STYLUS
+    case WSTYLUS_3D:
+        return "wacom-stylus-3btn-no-eraser";
+#endif
+    default:
+        if (!libwacom_stylus_has_eraser (wstylus)) {
+            if (libwacom_stylus_get_num_buttons (wstylus) >= 3)
+                return "wacom-stylus-3btn-no-eraser";
+            else
+                return "wacom-stylus-no-eraser";
+        }
+        else {
+            if (libwacom_stylus_get_num_buttons (wstylus) >= 3)
+                return "wacom-stylus-3btn";
+            else
+                return "wacom-stylus";
+        }
+}
+
+
+
+
+
+
+
+
+
+
+
+
 }
 
 static CsdWacomStylus *
@@ -157,7 +186,7 @@ csd_wacom_stylus_new (CsdWacomDevice    *device,
 	stylus->priv->name = g_strdup (libwacom_stylus_get_name (wstylus));
 	stylus->priv->settings = settings;
 	stylus->priv->type = libwacom_stylus_get_type (wstylus);
-	stylus->priv->icon_name = get_icon_name_from_type (stylus->priv->type);
+	stylus->priv->icon_name = get_icon_name_from_type (wstylus);
 	stylus->priv->has_eraser = libwacom_stylus_has_eraser (wstylus);
 	stylus->priv->num_buttons = libwacom_stylus_get_num_buttons (wstylus);
 
@@ -234,6 +263,10 @@ csd_wacom_stylus_get_stylus_type (CsdWacomStylus *stylus)
 		return WACOM_STYLUS_TYPE_STROKE;
 	case WSTYLUS_PUCK:
 		return WACOM_STYLUS_TYPE_PUCK;
+#ifdef HAVE_WACOM_3D_STYLUS
+    case WSTYLUS_3D:
+        return WACOM_STYLUS_TYPE_3D;
+#endif
 	default:
 		g_assert_not_reached ();
 	}
